pub enum NodeKind {
Show 59 variants
Block,
LetBinding,
Semi,
Paren,
Literal(LiteralKind),
Placeholder(PlaceholderKind, usize),
BinaryOp(BinOpKind),
UnaryOp(UnOpKind),
Range,
Call,
MethodCall,
FieldAccess,
Index,
Path,
Closure,
FnSignature,
Return,
Break,
Continue,
Assign,
Reference {
mutable: bool,
},
Tuple,
Array,
Repeat,
Cast,
StructInit,
Await,
Try,
If,
Match,
MatchArm,
Loop,
While,
ForLoop,
LetExpr,
PatWild,
PatPlaceholder(PlaceholderKind, usize),
PatTuple,
PatStruct,
PatOr,
PatLiteral,
PatReference {
mutable: bool,
},
PatSlice,
PatRest,
PatRange,
TypePlaceholder(PlaceholderKind, usize),
TypeReference {
mutable: bool,
},
TypeTuple,
TypeSlice,
TypeArray,
TypePath,
TypeImplTrait,
TypeInfer,
TypeUnit,
TypeNever,
FieldValue,
MacroCall {
name: String,
},
Opaque,
None,
}Expand description
The kind of a normalized AST node. Carries only non-child data (operator kinds, literal kinds, placeholder indices, mutability flags, macro names).
Variants
Block
LetBinding
Semi
Paren
Literal(LiteralKind)
Placeholder(PlaceholderKind, usize)
BinaryOp(BinOpKind)
UnaryOp(UnOpKind)
Range
Call
MethodCall
FieldAccess
Index
Path
Closure
FnSignature
Return
Break
Continue
Assign
Reference
Tuple
Array
Repeat
Cast
StructInit
Await
Try
If
Match
MatchArm
Loop
While
ForLoop
LetExpr
PatWild
PatPlaceholder(PlaceholderKind, usize)
PatTuple
PatStruct
PatOr
PatLiteral
PatReference
PatSlice
PatRest
PatRange
TypePlaceholder(PlaceholderKind, usize)
TypeReference
TypeTuple
TypeSlice
TypeArray
TypePath
TypeImplTrait
TypeInfer
TypeUnit
TypeNever
FieldValue
MacroCall
Opaque
None
Sentinel for absent optional children, ensuring fixed child positions for correct zip alignment in similarity comparison.